package com.miaxis.question.controller;

import com.miaxis.common.constant.Constants;
import java.util.List;
import java.util.Arrays;
import io.swagger.annotations.*;
import com.miaxis.common.core.domain.Response;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.bind.annotation.ModelAttribute;
import com.miaxis.common.annotation.Log;
import com.miaxis.common.core.controller.BaseController;
import com.miaxis.common.enums.BusinessTypeEnum;
import com.miaxis.question.domain.QuestionError;
import com.miaxis.question.service.IQuestionErrorService;
import com.miaxis.common.utils.poi.ExcelUtil;
import com.miaxis.common.core.page.ResponsePageInfo;

/**
 * 【错题】Controller
 *
 * @author miaxis
 * @date 2021-03-16
 */
@RestController
@RequestMapping("/error/error")
@Api(tags={"【小程序-错题】"})
public class QuestionErrorController extends BaseController{
    @Autowired
    private IQuestionErrorService questionErrorService;

    /**
     * 查询错题列表
     */
    @PreAuthorize("@ss.hasPermi('error:error:list')")
    @GetMapping("/list")
    @ApiOperation("查询错题列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum",value = "当前页码" ,dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize",value = "每页数据量" , dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<QuestionError> list(@ModelAttribute QuestionError questionError){
        startPage();
        List<QuestionError> list = questionErrorService.selectQuestionErrorList(questionError);
        return toResponsePageInfo(list);
    }

    /**
     * 导出错题列表
     */
    @PreAuthorize("@ss.hasPermi('error:error:export')")
    @Log(title = "错题", businessType = BusinessTypeEnum.EXPORT)
    @GetMapping("/export")
    @ApiOperation("导出错题列表Excel")
    public Response<String> export(@ModelAttribute QuestionError questionError){
        List<QuestionError> list = questionErrorService.selectQuestionErrorList(questionError);
        ExcelUtil<QuestionError> util = new ExcelUtil<QuestionError>(QuestionError.class);
        return util.exportExcel(list, "error");
    }

    /**
     * 获取错题详细信息
     */
    @PreAuthorize("@ss.hasPermi('error:error:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation("获取错题详细信息")
    public Response<QuestionError> getInfo(
            @ApiParam(name = "id", value = "错题参数", required = true)
            @PathVariable("id") Long id
    ){
        return Response.success(questionErrorService.getById(id));
    }

    /**
     * 新增错题
     */
    @PreAuthorize("@ss.hasPermi('error:error:add')")
    @Log(title = "错题", businessType = BusinessTypeEnum.INSERT)
    @PostMapping
    @ApiOperation("新增错题")
    public Response<Integer> add(@RequestBody QuestionError questionError){
        return toResponse(questionErrorService.save(questionError) ? 1 : 0);
    }

    /**
     * 修改错题
     */
    @PreAuthorize("@ss.hasPermi('error:error:edit')")
    @Log(title = "错题", businessType = BusinessTypeEnum.UPDATE)
    @PutMapping
    @ApiOperation("修改错题")
    public Response<Integer> edit(@RequestBody QuestionError questionError){
        return toResponse(questionErrorService.updateById(questionError) ? 1 : 0);
    }

    /**
     * 删除错题
     */
    @PreAuthorize("@ss.hasPermi('error:error:remove')")
    @Log(title = "错题", businessType = BusinessTypeEnum.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除错题")
    public  Response<Integer> remove(
            @ApiParam(name = "ids", value = "错题ids参数", required = true)
            @PathVariable Long[] ids
    ){
        return toResponse(questionErrorService.removeByIds(Arrays.asList(ids)) ? 1 : 0);
    }
}
